#
# MIT License
#
# Copyright (c) 2022 KuFlow
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#


from ._authentication_operations import AuthenticationOperations
from ._principal_operations import PrincipalOperations
from ._process_item_operations import ProcessItemOperations
from ._process_operations import ProcessOperations
from ._robot_operations import RobotOperations
from ._tenant_operations import TenantOperations
from ._tenant_user_operations import TenantUserOperations
from ._worker_operations import WorkerOperations


__all__ = [
    "AuthenticationOperations",
    "PrincipalOperations",
    "ProcessItemOperations",
    "ProcessOperations",
    "RobotOperations",
    "TenantOperations",
    "TenantUserOperations",
    "WorkerOperations",
]
